.. _references:

##########
References
##########

This page provides references to the used literature in this documentation and links to other useful packages.

Other Packages
--------------

* `ebltable package <https://github.com/me-manu/ebltable/>`_: small package for the interpolation and calculation of the absorption of gamma rays on the extragalactic background light (EBL)

* `gammaALPsPlot package <https://github.com/me-manu/gammaALPsPlot/>`_: package to creating plots of the ALP parameter space

Publications
------------

.. [Meyer2014] `Meyer; Montanino; Conrad (2014) <https://ui.adsabs.harvard.edu/abs/2014JCAP...09..003M/abstract>`_,
    "On detecting oscillations of gamma rays into axion-like particles in turbulent and coherent magnetic fields"

.. [Ajello2016] `Ajello et al. (2016) <https://ui.adsabs.harvard.edu/abs/2016PhRvL.116p1101A/abstract>`_,
    "Search for Spectral Irregularities due to Photon-Axionlike-Particle Oscillations with the Fermi Large Area Telescope"

.. [Meyer2013] `Meyer; Horns; Raue (2013) <https://ui.adsabs.harvard.edu/abs/2013PhRvD..87c5027M/abstract>`_
    "First lower limits on the photon-axion-like particle coupling from very high energy gamma-ray observations"

.. [Horns2012] `Horns et al. (2012) <https://ui.adsabs.harvard.edu/abs/2012PhRvD..86g5024H/abstract>`_
    "Hardening of TeV gamma spectrum of active galactic nuclei in galaxy clusters by conversions of photons into axionlike particles"

.. [Davies2021] `Davies; Meyer; Cotter (2021) <https://ui.adsabs.harvard.edu/abs/2020arXiv201108123D/abstract>`_
    "Relevance of Jet Magnetic Field Structure for Blazar ALP Searches"

.. [Planck2016] `Planck Collabroation (2016) <https://ui.adsabs.harvard.edu/abs/2016A%26A...596A.103P/abstract>`_
    "Planck intermediate results. XLII. Large-scale Galactic magnetic fields"

.. [Jansson2012] `Jansson; Farrar (2012) <https://ui.adsabs.harvard.edu/abs/2012ApJ...757...14J/abstract>`_
    "A New Model of the Galactic Magnetic Field"

.. [Pshirkov2011] `Pshirkov et al. (2011) <https://ui.adsabs.harvard.edu/abs/2011ApJ...738..192P/abstract>`_
    "Deriving the Global Structure of the Galactic Magnetic Field from Faraday Rotation Measures of Extragalactic Sources"

.. [ClausenBrown2011] `Clausen-Brown et al. (2011) <https://ui.adsabs.harvard.edu/abs/2011MNRAS.415.2081C/abstract>`_
    "Signatures of large-scale magnetic fields in active galactic nuclei jets: transverse asymmetries"

.. [Churazov2003] `Churazov et al. (2003) <https://ui.adsabs.harvard.edu/abs/2003ApJ...590..225C/abstract>`_
    "XMM-Newton Observations of the Perseus Cluster. I. The Temperature and Surface Brightness Structure"

.. [DeAngelis2011] `De Angelis; Galanti; Roncadelli (2011) <https://ui.adsabs.harvard.edu/abs/2011PhRvD..84j5030D/abstract>`_
    "Relevance of axionlike particles for very-high-energy astrophysics"

.. [Raffelt1988] `Raffelt; Stodolsky (1988) <https://ui.adsabs.harvard.edu/abs/1988PhRvD..37.1237R/abstract>`_
    "Mixing of the photon with low-mass particles"

.. [Dobrynina2015] `Dobrynina; Kartatsev; Raffelt (2015) <https://ui.adsabs.harvard.edu/abs/2015PhRvD..91h3003D/abstract>`_
    "Photon-photon dispersion of TeV gamma rays and its role for photon-ALP conversion"

.. [Gourgouliatos2010] `Gourgouliatos; Braithwaite; Lyutikov (2010) <https://ui.adsabs.harvard.edu/abs/2010MNRAS.409.1660G/abstract>`_
    "Structure of magnetic fields in intracluster cavities"
